==> patch-2.3.7.9.zip: app/language/en/report.php <==
<?php

return array(

	// Index method Language
	'indexPageName' => 'Reports',
	'dashboard' => 'Dashboard',
	'statistics' => 'Statistics',
	'overview' => 'Backup Overview',
	'restoreHistory' => 'Restore History',
	'restoreByUserName' => 'Restore By Username',
	'restoreByDeviceName' => 'Restore By Device Name',
	'longBackup' => 'Backups running for a long time',
	'currentBackup' => 'Current Backup',
	'noBackup' => 'Systems without backups',
	'storageUtilization' => 'Storage Utilization',
	'storageUtilizationByUser' => 'Storage Utilization By User',
	'storageUtilizedByPG' => 'Storage Utilization By BluKrypt',
	'restoreByDevice' => 'Restore By Device',
	'storageUtilizationByDevice' => 'Storage Utilization By Device',
	'failedBackup' => 'Failed Backup History',
	'failedBackupByUser' => 'Failed Backup details for a User',
	'failedBackupByDevice' => 'Failed Backup details for a Device',
	'storageTrend' => 'Storage Usage Trend',
	'blobTrend' => 'Cloud Storage Usage Trend',
	'backupTrend' => 'Data Growth Trend (Blukrypt to Cloud in GB)',
	'userDeviceHistory' => 'User Device Information',
	'dailyUserBackupOverview' => 'Daily User Backup Overview',
	'storageUtilizationReport' => 'Storage Utilization Report',
	'userBackupHistory' => 'User Backup History',
	'deviceUserHistory' => 'User Device Information',
	'deviceBackupHistory' => 'User Device Information',
	'lastBackupByUser' => 'Last Backup by user name',
	'lastBackupByDevice' => 'Last Backup by device name',
	'alertHistory' => 'Alert History',
	'alertByDevice' => 'Alert History By Device',
	'alertByUser' => 'Alert History By User',
	'alertByDate' => 'Alert History By Date',
	'userMigration' => 'User Migration',
	'userMigrationStatus' => 'User Migration Status',
	'syncCloudUsage' => 'Sync Cloud Usage',
	'lastAgentServerConnectionDetails' => 'Last Agent Server Connection Details',
	'syncCloudOverview' => 'Sync Overview Summary',

	// Common For all Methods
	'profileDisplay' => 'Account Details',
	'myDevices' => 'My Devices',
	'userSavedSuccess' => 'User Details have been updated successfully.',
        '204' => 'No sufficient data to export to excel',
	'421'       	=> 'Authentication token has <b>expired</b>',
	'417'       	=> '<b>User Limit</b> <b>exceeded.</b>',
	'403'       	=> '<b>Backup User Limit</b> <b>exceeded.</b>',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
	'cannotBlock'   => 'You cannot block <b>yourself</b>.  Please contact your Administrator for assistance.',
	'cannotDelete'  => 'You cannot delete <b>yourself</b>.   Please contact your Administrator for assistance.',
	'userBlocked'   => 'The selected user has been blocked successfully.',
	'userDeleted'   => 'The selected user has been deleted successfully.',
	'added_inclusion_folder'   		=> 'Folder <b>added</b> for inclusion.',
	'removed_inclusion_folder'   	=> 'Folder <b>removed</b>  successfully.',
	'added_exclusion_folder'   		=> 'Folder <b>added</b>  for exclusion.',
	'removed_exclusion_folder'   	=> 'Folder <b>removed</b> successfully.'
);

==> patch-2.5.3.18_3.zip: app/language/en/report.php <==
<?php

return array(

	// Index method Language
	'indexPageName' => 'Reports',
	'dashboard' => 'Dashboard',
	'statistics' => 'Statistics',
	'overview' => 'Backup Overview',
	'restoreHistory' => 'Restore History',
	'restoreByUserName' => 'Restore By Username',
	'restoreByDeviceName' => 'Restore By Device Name',
	'longBackup' => 'Backups running for a long time',
	'currentBackup' => 'Current Backup',
	'noBackup' => 'Systems without backups',
	'storageUtilization' => 'Storage Utilization',
	'storageUtilizationByUser' => 'Storage Utilization By User',
	'storageUtilizedByPG' => 'Storage Utilization By BluKrypt',
	'restoreByDevice' => 'Restore By Device',
	'storageUtilizationByDevice' => 'Storage Utilization By Device',
	'failedBackup' => 'Failed Backup History',
	'failedBackupByUser' => 'Failed Backup details for a User',
	'failedBackupByDevice' => 'Failed Backup details for a Device',
	'storageTrend' => 'Storage Usage Trend',
	'blobTrend' => 'Cloud Storage Usage Trend',
	'backupTrend' => 'Data Growth Trend (Blukrypt to Cloud in GB)',
	'userDeviceHistory' => 'User Device Information',
	'dailyUserBackupOverview' => 'Daily User Backup Overview',
	'storageUtilizationReport' => 'Storage Utilization Report',
	'userBackupHistory' => 'User Backup History',
	'deviceUserHistory' => 'User Device Information',
	'deviceBackupHistory' => 'User Device Information',
	'lastBackupByUser' => 'Last Backup by user name',
	'lastBackupByDevice' => 'Last Backup by device name',
	'alertHistory' => 'Alert History',
	'alertByDevice' => 'Alert History By Device',
	'alertByUser' => 'Alert History By User',
	'alertByDate' => 'Alert History By Date',
	'userMigration' => 'User Migration',
	'userMigrationStatus' => 'User Migration Status',
	'syncCloudUsage' => 'Sync Cloud Usage',
	'lastAgentServerConnectionDetails' => 'Device Heartbeat Report',
	'syncCloudOverview' => 'Sync Overview Summary',
	'userBackupSummary' => 'User Backup Summary',
	'usersWithoutDevices' => 'Users Without Active Devices',

	// Common For all Methods
	'profileDisplay' => 'Account Details',
	'myDevices' => 'My Devices',
	'userSavedSuccess' => 'User Details have been updated successfully.',
        '204' => 'No sufficient data to export to excel',
	'421'       	=> 'Authentication token has <b>expired</b>',
	'417'       	=> '<b>User Limit</b> <b>exceeded.</b>',
	'403'       	=> '<b>Backup User Limit</b> <b>exceeded.</b>',
	'500'       	=> 'Details couldn\'t be saved because the Server did not respond or is unreachable.  Please try again after a while.  If the failure persists, you may need to contact your Administrator for assistance.',
	'0'         	=> '<b>The Server is unreachable</b>. Please try again after some time.  If the failure persists, you may need to contact your Administrator for assistance.',
	'default'   	=> 'We\'re sorry, but something went <b>wrong</b>.  Please try again later.  If the failure persists, please contact your Administrator for assistance',
	'noData'    	=> 'Couldn\'t save the data because of errors in one or more fields, Please check and try submitting again',
	'cannotBlock'   => 'You cannot block <b>yourself</b>.  Please contact your Administrator for assistance.',
	'cannotDelete'  => 'You cannot delete <b>yourself</b>.   Please contact your Administrator for assistance.',
	'userBlocked'   => 'The selected user has been blocked successfully.',
	'userDeleted'   => 'The selected user has been deleted successfully.',
	'added_inclusion_folder'   		=> 'Folder <b>added</b> for inclusion.',
	'removed_inclusion_folder'   	=> 'Folder <b>removed</b>  successfully.',
	'added_exclusion_folder'   		=> 'Folder <b>added</b>  for exclusion.',
	'removed_exclusion_folder'   	=> 'Folder <b>removed</b> successfully.'
);
